@@ -4,6 +4,7 @@
 
 #include <linux/types.h>
 #include <asm/irqvec.h>
+#include <linux/sched.h>
 
 #ifdef CONFIG_IRQ
 
@@ -28,26 +29,14 @@ __attribute__((naked, alias(#func), used)) static void __vector_##vec(void);
 
 #define REQUEST_NAKED_IRQ(vec, func) REQUEST_NAKED_IRQ_(vec, func)
 
-#endif
+#endif /* CONFIG_IRQ */
 
 #ifdef CONFIG_IRQ_CLASSIC
 
-#define REQUEST_IRQ_(vec, func) \
-static void func(u8); \
-__attribute__((signal)) void __vector_##vec(void) { \
-	func(vec); \
-	resched_after_irq(); \
-}
-#define REQUEST_IRQ(vec, func) REQUEST_IRQ_(vec, func)
+#define REQUEST_IRQ REQUEST_DIRECT_IRQ
+#define REQUEST_IRQ_NO_RESCHED REQUEST_DIRECT_IRQ_NO_RESCHED
 
-#define REQUEST_IRQ_NO_RESCHED_(vec, func) \
-static void func(u8); \
-__attribute__((signal)) void __vector_##vec(void) { \
-	func(vec); \
-}
-#define REQUEST_IRQ_NO_RESCHED(vec, func) REQUEST_IRQ_NO_RESCHED_(vec, func)
-
-#elif defined CONFIG_IRQ_COMMON_STATIC
+#elif defined CONFIG_IRQ_COMMON
 
 #define REQUEST_IRQ_(vec, func) \
 static void func(u8); \
@@ -57,23 +46,12 @@ void _vector_##vec(u8 v) { \
 #define REQUEST_IRQ(vec, func) REQUEST_IRQ_(vec, func)
 #define REQUEST_IRQ_NO_RESCHED(vec, func) REQUEST_IRQ_(vec, func)
 
-#elif defined CONFIG_IRQ_COMMON_DYNAMIC
+#endif /* CONFIG_IRQ_COMMON */
 
-#include <linux/init.h>
+#ifdef CONFIG_IRQ_COMMON_DYNAMIC
 
 void request_irq(u8 vector, void (*func)(u8 vector));
 
-#define REQUEST_IRQ_(vec, func) \
-static void func(u8); \
-static int request_vector_##vec(void) { \
-	request_irq(vec, func); \
-	return 0; \
-} \
-initcall(request_vector_##vec)
-
-#define REQUEST_IRQ(vec, func) REQUEST_IRQ_(vec, func)
-#define REQUEST_IRQ_NO_RESCHED(vec, func) REQUEST_IRQ_(vec, func)
-
-#endif
+#endif /* CONFIG_IRQ_COMMON_DYNAMIC */
 
 #endif /* _ASM_AVR_INTERRUPT_H */
