@@ -17,19 +17,39 @@ typedef unsigned char irqflags_t;
 #define irqs_disabled_flags(flags) (!(flags & SREG_I))
 #define irqs_disabled()            (!(in(SREG) & SREG_I))
 
-#define set_sleep_mode(sm)  out(MCUCR, in(MCUCR) | sm)
+
+#ifdef SMCR
+#define SMCR_         SMCR
+#define SMCR_SE_      SMCR_SE
+#define SMCR_SM_IDLE_ SMCR_SM_IDLE
+#elif defined(MCUCR_SM_IDLE)
+#define SMCR_         MCUCR
+#define SMCR_SE_      MCUCR_SE
+#define SMCR_SM_IDLE_ MCUCR_SM_IDLE
+#endif
+
+#ifdef SMCR_
+
+#define set_sleep_mode(sm)  out(SMCR_, in(SMCR_) | sm)
 
 #define do_sleep() do { \
-	out(MCUCR, in(MCUCR) | MCUCR_SE); \
+	out(SMCR_, in(SMCR_) | SMCR_SE_); \
 	asm volatile("sleep"); \
-	out(MCUCR, in(MCUCR) & ~MCUCR_SE); \
+	out(SMCR_, in(SMCR_) & ~SMCR_SE_); \
 } while(0);
 
+#else
+
+#define set_sleep_mode(sm) do{}while(0)
+#define do_sleep()         do{}while(0)
+
+#endif
+
 #ifdef CONFIG_WAKE_SEMA_FROM_IRQ	
 
 #define safe_halt()    do { \
 	local_irq_enable(); \
-	set_sleep_mode(MCUCR_SM_IDLE); \
+	set_sleep_mode(SMCR_SM_IDLE_); \
 	do_sleep(); \
 } while(0)
 
@@ -38,7 +58,7 @@ typedef unsigned char irqflags_t;
 #define safe_halt()           do { \
 	local_irq_enable(); \
 	for(;;) { \
-		set_sleep_mode(MCUCR_SM_IDLE); \
+		set_sleep_mode(SMCR_SM_IDLE_); \
 		do_sleep(); \
 	} \
 } while(0)
