@@ -33,10 +33,13 @@ extern int main(void);
 __attribute__ ((naked, used, section (".init9")))
 void __call_main(void) {
 #ifndef CONFIG_SCHEDULER
+#ifdef CONFIG_MAIN_FUNCTION
+	main();
+#endif
 	local_irq_enable();
 	for (;;);
 #else
-	schedule();
+	kill_current();
 #endif
 }
 
