@@ -6,7 +6,7 @@
 
 #define section_func(initfunc, sec, prefix) \
 	FORCE_STATIC(initfunc); \
-	void prefix##_##initfunc(void) __attribute__((section("." #sec), naked)); \
+	void prefix##_##initfunc(void) __attribute__((section("." #sec), naked, used)); \
 	void prefix##_##initfunc(void) { initfunc(); }
 
 #define early_initcall(func)  section_func(func, init5, early)
