@@ -4,11 +4,11 @@
 
 #include <linux/kern_levels.h>
 
-#include <asm/flash.h>
+#include <asm/rodata.h>
 
 #ifdef CONFIG_PRINTK
 
-extern void printk_(const char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
+extern void printk_(__rodata char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
 
 #define printk__(lvl, fmt, ...)  do { if (lvl <= KERN_LOGLEVEL) printk_(FMTSTR(fmt), ##__VA_ARGS__); } while(0)
 #define printk(fmt, ...) printk__(fmt, ##__VA_ARGS__)
