@@ -15,7 +15,7 @@ struct timer {
 	struct timer *prev;
 #endif
 	jiffies_t expires;
-	void (*function)(void);
+	void (*function)(struct timer *timer);
 };
 
 void add_timer(struct timer *timer);
