@@ -3,7 +3,8 @@
 #define _RUPSCHED_VDEVPRINTF_H
 
 #include <linux/cdev.h>
+#include <asm/rodata.h>
 
-void vdevprintf(const char __flash *fmt, struct ocdev *dev, va_list args);
+void vdevprintf(char __rodata *fmt, struct ocdev *dev, va_list args);
 
 #endif /* _RUPSCHED_VDEVPRINTF_H */
\ No newline at end of file
