@@ -11,7 +11,7 @@
 
 extern struct ocdev kernel_console;
 
-void printk_(const char *fmt, ...) {
+void printk_(__rodata char *fmt, ...) {
         va_list ap;
 
         va_start(ap, fmt);
