@@ -7,19 +7,18 @@
 #define s16 int16_t
 #define u8 uint8_t
 #include <stdio.h>
-#define __flashdata_decl
-#define flash_read(x) (x)
+#define __rodata const
 
 #else
 
 #include <linux/types.h>
-#include <asm/flash.h>
+#include <asm/rodata.h>
 
 #endif
 
 #define QUADRANT_SIZE 180
 
-static u16 __flashdata_decl SINUS_QUADRANT1[QUADRANT_SIZE+1] = {
+static u16 __rodata SINUS_QUADRANT1[QUADRANT_SIZE+1] = {
 #include "sin_11.h"
 };
 
@@ -31,14 +30,14 @@ s16 sin_11(u16 deg) {
 		deg -= QUADRANT_SIZE * 4;
 	if (deg <= QUADRANT_SIZE) {
 #endif
-		retval = flash_read(SINUS_QUADRANT1[(u8)deg]);
+		retval = SINUS_QUADRANT1[(u8)deg];
 #if 0
 	} else if (deg <= QUADRANT_SIZE*2) {
-		retval = flash_read(SINUS_QUADRANT1[(u8)(QUADRANT_SIZE*2 - deg)]);
+		retval = SINUS_QUADRANT1[(u8)(QUADRANT_SIZE*2 - deg)];
 	} else if (deg <= QUADRANT_SIZE*3) {
-		retval = -flash_read(SINUS_QUADRANT1[(u8)(deg - QUADRANT_SIZE*2)]);
+		retval = -SINUS_QUADRANT1[(u8)(deg - QUADRANT_SIZE*2)];
 	} else {
-		retval = -flash_read(SINUS_QUADRANT1[(u8)(QUADRANT_SIZE*4 - deg)]);
+		retval = -SINUS_QUADRANT1[(u8)(QUADRANT_SIZE*4 - deg)];
 	}
 #endif
 	return retval;
