@@ -30,8 +30,7 @@
 #include <rupsched/vdevprintf.h>
 
 #include <linux/compiler.h>
-
-#include <asm/flash.h>
+#include <linux/string.h>
 
 #endif
 
@@ -74,12 +73,12 @@ extern char* __ultoa_invert(u32 num, char const *buf, u8 base);
 #define DEFAULT_PAD ' '
 #endif
 
-#ifndef CONFIG_PRINF_ZPAD
+#ifndef CONFIG_PRINTF_ZPAD
 #define num_is_pad(ch, width)  0
 #elif CONFIG_PRINTF_MAX_WIDTH < 10
 #define num_is_pad(ch, width)  (ch == '0')
 #else
-#define num_is_pad(ch, width)  (ch == '0' || !width)
+#define num_is_pad(ch, width)  (ch == '0' && !width)
 #endif
 
 #if defined(CONFIG_PRINTF_NUM_LPAD) || defined(CONFIG_PRINTF_STR_LPAD)
@@ -261,17 +260,8 @@ char *decode_oct(char * buf, printf_oct_t value) {
 }
 
 
-#ifdef __TEST__
-
 #define fmt_getc(fmt)    (*fmt++)
 
-#else
-
-#define fmt_getc(fmt)    (flash_read(*fmt++))
-// #define fmt_getc(fmt)    flash_read8_inc(fmt)
-
-#endif
-
 #ifdef CONFIG_PRINTF_o
 #define BUF_SIZE_o  (sizeof(printf_oct_t) * 268 + 99) / 100
 #else
@@ -314,7 +304,7 @@ char *decode_num(char *buf, printf_arg_t arg, char ch) {
 #endif
 }
 
-void vdevprintf(const char __flash *fmt, struct ocdev *dev, va_list args) {
+void vdevprintf(char __rodata *fmt, struct ocdev *dev, va_list args) {
 	char ch;
 	char width;
 	char sign;
@@ -412,6 +402,7 @@ nextfmt: __maybe_unused;
 
 			{
 				char *src = va_arg(args, char*);
+				char c;
 #ifndef CONFIG_PRINTF_STRPAD
 				width = 0;
 #endif
@@ -423,14 +414,13 @@ nextfmt: __maybe_unused;
 					width--;
 					putc(dev, ' ');
 				}
-
-				while ((ch =
-					ch_s_is_lower(ch) ?
+				while ((c = ch_s_is_lower(ch) ?
 					(*src++) :
-					flash_read8_inc(src))) {
-					putc(dev, ch);
+					*((char __rodata*)(uintptr_t)(src++))
+				)) {
+					putc(dev, c);
 				}
-				
+
 				while (width > 0) {
 					width--;
 					putc(dev, ' ');
