@@ -3,9 +3,11 @@
 
 #include <linux/init.h>
 #include <linux/sched.h>
+#include <linux/task.h>
 
 #include <asm/io.h>
 #include <asm/system.h>
+#include <asm/gpio.h>
 
 
 //#define NO_WAIT
@@ -22,41 +24,49 @@ static void wait(void) {
 }
 #endif /* NO_WAIT */
 
+#ifdef CONFIG_STACK_SIZE_FIXED
 struct task_struct o1;
-void fo1(void *arg) {
+struct task_struct o2;
+#endif
+
+__kthread_func void fo1(void *arg) {
 	for (;;) {
 		wait();
-		out(PORTB, in(PORTB) ^ 1);
+		gpio_toggle(GPIO_B0);
 	}
 }
-struct task_struct o2;
-void fo2(void *arg) {
+__kthread_func void fo2(void *arg) {
 	for (;;) {
 		wait();
-		out(PORTB, in(PORTB) ^ 2);
+		gpio_toggle(GPIO_B1);
 	}
 }
 
 static int init_sched_other_test(void) {
 	int i;
-	out(DDRB, 0x3f);
-	out(DDRC, 0x3f);
+
+	gpiogroup_set_output_v(GPIO_B0, GPIO_B0_NBITS, 0x3f);
 	wait();
 	wait();
 	wait();
 	wait();
-	out(PORTB, 7);
+	gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, 7);
 	for (i = 0; i <= 7; i++) {
 		wait();
-		out(PORTB, i);
+		gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, i);
 	}
 	wait();
-	out(PORTB, 0);
+	gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, 0);
 
+#ifdef CONFIG_STACK_SIZE_FIXED
 	kernel_thread(&o1, fo1, NULL, -1);
 	kernel_thread(&o2, fo2, NULL, -2);
+#else
+	kernel_thread(128, fo1, NULL, -1);
+	kernel_thread(128, fo2, NULL, -2);
+#endif
 
-	out(PORTB, 1);
+	gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, 1);
 	return 0;
 }
 
