@@ -2,11 +2,13 @@
 // Copyright (c) 2008, 2017-2019 Rupert Eibauer. All rights reserved.
 
 #include <linux/timer.h>
+#include <linux/sched.h>
+#include <linux/task.h>
 #include <linux/printk.h>
 #include <linux/init.h>
 
 #include <asm/system.h>
-#include <asm/io.h>
+#include <asm/gpio.h>
 
 //#define NO_WAIT
 #ifdef NO_WAIT
@@ -28,12 +30,14 @@ static void wait(void) {
 */
 
 struct completion s;
+#ifdef CONFIG_STACK_SIZE_FIXED
 struct task_struct tw;
-void fw(void *arg)
+#endif
+__kthread_func void fw(void *arg)
 {
 	for (;;)
 	{
-		out(PORTB,  1);
+		gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, 1);
 		wait();
 		wait_for_completion(&s);
 		printf("a\n");
@@ -41,15 +45,15 @@ void fw(void *arg)
 }
 
 static struct timer test_timer;
-static void timer_callback(void) {
-	out(PORTB, 2);
+static void timer_callback(struct timer *timer) {
+	gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, 2);
 	complete_from_irq(&s);
 	printf("Timer\n");
 #ifdef CONFIG_DEL_TIMER
-	mod_timer(&test_timer, test_timer.expires + HZ);
+	mod_timer(timer, test_timer.expires + HZ);
 #else
 	test_timer.expires += HZ;
-	add_timer(&test_timer);
+	add_timer(timer);
 #endif
 	
 }
@@ -60,25 +64,29 @@ static struct timer test_timer = {
 
 static int init_semaphore_timer_test(void) {
 	int i;
+
 	printk(KERN_NOTICE "HELLO WORLD!\n");
-	out(DDRB, 0x3f);
-	out(DDRC, 0x3f);
+	gpiogroup_set_output(GPIO_B0, GPIO_B0_NBITS, 0x3f);
 	local_irq_enable();
 	add_timer(&test_timer);
 	wait();
 	wait();
 	wait();
 	wait();
-	out(PORTB, 7);
+	gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, 7);
 	for (i = 0; i <= 7; i++) {
 		wait();
-		out(PORTB, i);
+		gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, i);
 	}
 	wait();
-	out(PORTB, 0);
+	gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, 0);
 
+#ifdef CONFIG_STACK_SIZE_FIXED
 	kernel_thread(&tw, fw, NULL, 2); /* High-prio waiter */
-	out(PORTB, 1);
+#else
+	kernel_thread(128, fw, NULL, 2); /* High-prio waiter */
+#endif
+	gpiogroup_out(GPIO_B0, GPIO_B0_NBITS, 1);
 	printk(KERN_NOTICE "calling schedule!\n");
 	return 0;
 }
