@@ -1,6 +1,7 @@
 // SPDX-License-Identifier: GPL-2.0
 #include <linux/printk.h>
 #include <linux/sched.h>
+#include <linux/task.h>
 #include <linux/init.h>
 #include <linux/kernel.h>
 
@@ -12,7 +13,6 @@
 
 
 extern void dump_memory(void);
-extern void report_stack_usage(void);
 
 void usart_thread(void *arg) {
 	char ch;
@@ -48,11 +48,17 @@ void usart_thread(void *arg) {
 	}
 }
 
+#ifdef CONFIG_STACK_SIZE_FIXED
 static struct task_struct usart_task;
+#endif
 
 static int init_usart_test(void) {
 	printk(KERN_NOTICE "\n\n\nHello World from init!\n");
+#ifdef CONFIG_STACK_SIZE_FIXED
 	kernel_thread(&usart_task, usart_thread, (void*)0x1234, 1);
+#else
+	kernel_thread(128, usart_thread, (void*)0x1234, 1);
+#endif
 	return 0;
 }
 
